Enum InlineNode

pub enum InlineNode {
    Text(String),
    Emphasis(Vec<InlineNode>),
    Strong(Vec<InlineNode>),
    Strike(Vec<InlineNode>),
    InlineCode(String),
    Link {
        url: String,
        title: Option<String>,
        content: Vec<InlineNode>,
    },
    Image {
        url: String,
        title: Option<String>,
        alt: String,
    },
    InlineContainer(Vec<InlineNode>),
    HtmlElement(HtmlElement),
    SoftBreak,
    HardBreak,
}
Inline node type, representing inline elements used within block-level elements

Variants



Text(String)

Plain text



Emphasis(Vec<InlineNode>)

Emphasis (italic)



Strong(Vec<InlineNode>)

Strong emphasis (bold)



Strike(Vec<InlineNode>)

Strikethrough



InlineCode(String)

Inline code

Link

Fields

url: String

Link URL

title: Option<String>

Optional link title

content: Vec<InlineNode>

Link text



Image

Image

Fields

url: String

Image URL

title: Option<String>

Optional image title

alt: String

Alternative text



InlineContainer(Vec<InlineNode>)

Inline element collection, without formatting and line breaks



HtmlElement(HtmlElement)

HTML inline element



SoftBreak

Soft break (single line break)



HardBreak

Hard break (two spaces followed by a line break, or backslash followed by a line break)

Implementations

Source

impl InlineNode

pub fn into_node(self) -> Node

Converts an InlineNode to Node