pub enum InlineNode {
Text(String),
Emphasis(Vec<InlineNode>),
Strong(Vec<InlineNode>),
Strike(Vec<InlineNode>),
InlineCode(String),
Link {
url: String,
title: Option<String>,
content: Vec<InlineNode>,
},
Image {
url: String,
title: Option<String>,
alt: String,
},
InlineContainer(Vec<InlineNode>),
HtmlElement(HtmlElement),
SoftBreak,
HardBreak,
}Expand description
Inline node type, representing inline elements used within block-level elements
Variants
Text(String)
Plain text
Emphasis(Vec<InlineNode>)
Emphasis (italic)
Strong(Vec<InlineNode>)
Strong emphasis (bold)
Strike(Vec<InlineNode>)
Strikethrough
InlineCode(String)
Inline code
Link
Link
Fields

content: Vec<InlineNode>Link text
Image
Image
InlineContainer(Vec<InlineNode>)
Inline element collection, without formatting and line breaks
HtmlElement(HtmlElement)
HTML inline element
SoftBreak
Soft break (single line break)
HardBreak
Hard break (two spaces followed by a line break, or backslash followed by a line break)
Implementations