Enum Node

pub enum Node {
Show 21 variants Document(Vec<Node>), Heading { level: u8, content: Vec<Node>, }, Paragraph(Vec<Node>), BlockQuote(Vec<Node>), CodeBlock { language: Option<String>, content: String, }, UnorderedList(Vec<ListItem>), OrderedList { start: u32, items: Vec<ListItem>, }, ThematicBreak, Table { headers: Vec<Node>, rows: Vec<Vec<Node>>, alignments: Vec<Alignment>, }, HtmlBlock(String), Text(String), Emphasis(Vec<Node>), Strong(Vec<Node>), Strike(Vec<Node>), InlineCode(String), Link { url: String, title: Option<String>, content: Vec<Node>, }, Image { url: String, title: Option<String>, alt: Vec<Node>, }, InlineContainer(Vec<Node>), HtmlElement(HtmlElement), SoftBreak, HardBreak,
}
Main node type, representing an element in a CommonMark document

Variants



Document(Vec<Node>)

Root document node, contains child nodes



Heading

Heading, contains level (1-6) and inline content

Fields

level: u8

Heading level, 1-6

content: Vec<Node>

Heading content, containing inline elements



Paragraph(Vec<Node>)

Paragraph node, containing inline elements



BlockQuote(Vec<Node>)

Block quote, containing any block-level elements



CodeBlock

Code block, containing optional language identifier and content

Fields

language: Option<String>

Optional language identifier

content: String

Code content



UnorderedList(Vec<ListItem>)

Unordered list, containing list items



OrderedList

Ordered list, containing starting number and list items

Fields

start: u32

List starting number

items: Vec<ListItem>

List items



ThematicBreak

Thematic break (horizontal rule)



Table

Table

Fields

headers: Vec<Node>

Header cells

rows: Vec<Vec<Node>>

Table rows, each row containing multiple cells

alignments: Vec<Alignment>

Column alignments



HtmlBlock(String)

HTML block



Text(String)

Plain text



Emphasis(Vec<Node>)

Emphasis (italic)



Strong(Vec<Node>)

Strong emphasis (bold)



Strike(Vec<Node>)

Strikethrough



InlineCode(String)

Inline code

Link

Fields

url: String

Link URL

title: Option<String>

Optional link title

content: Vec<Node>

Link text



Image

Image

Fields

url: String

Image URL

title: Option<String>

Optional image title

alt: Vec<Node>

Alternative text, containing inline elements



InlineContainer(Vec<Node>)

Inline element collection, without formatting and line breaks



HtmlElement(HtmlElement)

HTML inline element



SoftBreak

Soft break (single line break)



HardBreak

Hard break (two spaces followed by a line break, or backslash followed by a line break)

Implementations

Source

impl Node

pub fn is_block(&self) -> bool

Check if a node is a block-level node

pub fn is_inline(&self) -> bool

Check if a node is an inline node