CustomErrorFactory

Trait CustomErrorFactory 

pub trait CustomErrorFactory {
    // Required method
    fn create_error(&self) -> WriteError;
}
Trait to define custom error factories for WriteError

This trait allows extending WriteError with custom error constructors while allowing both library and user code to define their own error types.

Required Methods

fn create_error(&self) -> WriteError

Create an error from this factory

Implementors