pub struct HtmlWriterOptions {
pub code_block_language_class_prefix: Option<EcoString>,
pub strict: bool,
}Expand description
Options for configuring the HTML rendering process.
HtmlWriterOptions allows customizing how HTML is generated when rendering
CommonMark content. These options can be used directly with an HtmlWriter or
can be derived from a CommonMarkWriter’s options when rendering HTML elements
within CommonMark content.
Example
use cmark_writer::{HtmlWriter, HtmlWriterOptions};
// Create custom HTML rendering options
let options = HtmlWriterOptions {
strict: true,
code_block_language_class_prefix: Some("language-".into()),
#[cfg(feature = "gfm")]
enable_gfm: true,
#[cfg(feature = "gfm")]
gfm_disallowed_html_tags: vec!["script".into()],
};
// Use the options with an HtmlWriter
let mut writer = HtmlWriter::with_options(options);Fields
code_block_language_class_prefix: Option<EcoString>A prefix for the class name applied to fenced code blocks. For example, if set to “lang-”, a Rust code block might get class “lang-rust”. If None, no language class is added.
strict: boolDetermines if HTML parsing/rendering errors should be strict (panic/Err) or lenient (warn and attempt to recover/textualize).